@@ -1,12 +1,12 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="nl">
+<TS version="2.1" language="nl_NL">
 <context>
     <name>AudioItem</name>
     <message>
         <location filename="../../src/timeline/widgets/AudioItem.cc" line="+125"/>
         <source>Save File</source>
-        <translation type="unfinished"></translation>
+        <translation>Bestand opslaan</translation>
     </message>
 </context>
 <context>
@@ -27,22 +27,22 @@
     <message>
         <location filename="../../src/dialogs/RoomSettings.cpp" line="+34"/>
         <source>APPLY</source>
-        <translation type="unfinished"></translation>
+        <translation>TOEPASSEN</translation>
     </message>
     <message>
         <location line="+2"/>
         <source>CANCEL</source>
-        <translation type="unfinished">ANNULEREN</translation>
+        <translation>ANNULEREN</translation>
     </message>
     <message>
         <location line="+9"/>
         <source>Name</source>
-        <translation type="unfinished">Naam</translation>
+        <translation>Naam</translation>
     </message>
     <message>
         <location line="+2"/>
         <source>Topic</source>
-        <translation type="unfinished">Onderwerp</translation>
+        <translation>Onderwerp</translation>
     </message>
 </context>
 <context>
@@ -50,7 +50,7 @@
     <message>
         <location filename="../../src/timeline/widgets/FileItem.cc" line="+111"/>
         <source>Save File</source>
-        <translation type="unfinished"></translation>
+        <translation>Bestand opslaan</translation>
     </message>
 </context>
 <context>
@@ -58,7 +58,7 @@
     <message>
         <location filename="../../src/timeline/widgets/ImageItem.cc" line="+229"/>
         <source>Save image</source>
-        <translation type="unfinished"></translation>
+        <translation>Afbeelding opslaan</translation>
     </message>
 </context>
 <context>
@@ -66,7 +66,7 @@
     <message>
         <location filename="../../src/LoginPage.cc" line="+79"/>
         <source>Matrix ID</source>
-        <translation>Matrix ID</translation>
+        <translation>Matrix-id</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -81,7 +81,7 @@
     <message>
         <location line="+19"/>
         <source>LOGIN</source>
-        <translation>LOGIN</translation>
+        <translation>INLOGGEN</translation>
     </message>
     <message>
         <location line="+128"/>
@@ -99,17 +99,17 @@
     <message>
         <location line="+5"/>
         <source>Login endpoint was not found on the server</source>
-        <translation>De login eindpunt is niet gevonden op de server</translation>
+        <translation>Het inlog-endpoint is niet aangetroffen op de server</translation>
     </message>
     <message>
         <location line="+6"/>
         <source>An unknown error occured. Please try again.</source>
-        <translation>Er is een onbekende fout opgetreden. Probeer het alsjeblieft opnieuw.</translation>
+        <translation>Er is een onbekende fout opgetreden. Probeer het opnieuw.</translation>
     </message>
     <message>
         <location line="+23"/>
         <source>Malformed response. Possibly not a Matrix server</source>
-        <translation>Onjuist antwoord ontvangen. Het is mogelijk geen Matrix server</translation>
+        <translation>Onjuist antwoord ontvangen: dit is mogelijk geen Matrix server</translation>
     </message>
 </context>
 <context>
@@ -117,12 +117,12 @@
     <message>
         <location filename="../../src/dialogs/MemberList.cpp" line="+79"/>
         <source>Room members</source>
-        <translation type="unfinished"></translation>
+        <translation>Kamerleden</translation>
     </message>
     <message>
         <location line="+10"/>
         <source>SHOW MORE</source>
-        <translation type="unfinished"></translation>
+        <translation>MEER TONEN</translation>
     </message>
 </context>
 <context>
@@ -130,7 +130,7 @@
     <message>
         <location filename="../../src/QuickSwitcher.cc" line="+70"/>
         <source>Search for a room...</source>
-        <translation type="unfinished"></translation>
+        <translation>Zoek een kamer...</translation>
     </message>
 </context>
 <context>
@@ -148,17 +148,17 @@
     <message>
         <location line="+4"/>
         <source>Password confirmation</source>
-        <translation>Wachtwoord bevestiging</translation>
+        <translation>Wachtwoord bevestigen</translation>
     </message>
     <message>
         <location line="+4"/>
         <source>Home Server</source>
-        <translation>Home server</translation>
+        <translation>Thuisserver</translation>
     </message>
     <message>
         <location line="+17"/>
         <source>REGISTER</source>
-        <translation>REGISTREER</translation>
+        <translation>REGISTREREN</translation>
     </message>
     <message>
         <location line="+76"/>
@@ -168,7 +168,7 @@
     <message>
         <location line="+2"/>
         <source>Password is not long enough (min 8 chars)</source>
-        <translation>Het wachtwoord is niet lang genoeg (minimaal 8 karakters)</translation>
+        <translation>Het wachtwoord is niet lang genoeg (minimaal 8 tekens)</translation>
     </message>
     <message>
         <location line="+2"/>
@@ -178,7 +178,7 @@
     <message>
         <location line="+2"/>
         <source>Invalid server name</source>
-        <translation>Ongeldige server naam</translation>
+        <translation>Ongeldige servernaam</translation>
     </message>
 </context>
 <context>
@@ -186,17 +186,17 @@
     <message>
         <location filename="../../src/RoomInfoListItem.cc" line="+78"/>
         <source>Leave room</source>
-        <translation type="unfinished"></translation>
+        <translation>Kamer verlaten</translation>
     </message>
     <message>
         <location line="+153"/>
         <source>Accept</source>
-        <translation type="unfinished"></translation>
+        <translation>Accepteren</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Decline</source>
-        <translation type="unfinished"></translation>
+        <translation>Afwijzen</translation>
     </message>
 </context>
 <context>
@@ -204,12 +204,12 @@
     <message>
         <location filename="../../src/SideBarActions.cc" line="+36"/>
         <source>Create new room</source>
-        <translation type="unfinished"></translation>
+        <translation>Nieuwe kamer creëren</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Join a room</source>
-        <translation type="unfinished"></translation>
+        <translation>Kamer betreden</translation>
     </message>
 </context>
 <context>
@@ -217,17 +217,17 @@
     <message>
         <location filename="../../src/TextInputWidget.cc" line="+445"/>
         <source>Write a message...</source>
-        <translation>Type een bericht...</translation>
+        <translation>Typ een bericht...</translation>
     </message>
     <message>
         <location line="+108"/>
         <source>Select a file</source>
-        <translation type="unfinished"></translation>
+        <translation>Kies een bestand</translation>
     </message>
     <message>
         <location line="+0"/>
         <source>All Files (*)</source>
-        <translation type="unfinished"></translation>
+        <translation>Alle bestanden (*)</translation>
     </message>
 </context>
 <context>
@@ -235,22 +235,22 @@
     <message>
         <location filename="../../src/TopRoomBar.cc" line="+87"/>
         <source>Invite users</source>
-        <translation type="unfinished"></translation>
+        <translation>Gebruikers uitnodigen</translation>
     </message>
     <message>
         <location line="+6"/>
         <source>Members</source>
-        <translation type="unfinished"></translation>
+        <translation>Leden</translation>
     </message>
     <message>
         <location line="+5"/>
         <source>Leave room</source>
-        <translation type="unfinished"></translation>
+        <translation>Kamer verlaten</translation>
     </message>
     <message>
         <location line="+5"/>
         <source>Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Instellingen</translation>
     </message>
 </context>
 <context>
@@ -258,12 +258,12 @@
     <message>
         <location filename="../../src/TrayIcon.cc" line="+116"/>
         <source>Show</source>
-        <translation>Laten zien</translation>
+        <translation>Tonen</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Quit</source>
-        <translation>Sluiten</translation>
+        <translation>Afsluiten</translation>
     </message>
 </context>
 <context>
@@ -271,12 +271,12 @@
     <message>
         <location filename="../../src/TypingDisplay.cc" line="+26"/>
         <source> is typing</source>
-        <translation type="unfinished"></translation>
+        <translation> is aan het typen</translation>
     </message>
     <message>
         <location line="+2"/>
         <source> are typing</source>
-        <translation type="unfinished"></translation>
+        <translation> zijn aan het typen</translation>
     </message>
 </context>
 <context>
@@ -284,47 +284,47 @@
     <message>
         <location filename="../../src/UserSettingsPage.cc" line="+121"/>
         <source>User Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Gebruikersinstellingen</translation>
     </message>
     <message>
         <location line="+15"/>
         <source>Minimize to tray</source>
-        <translation type="unfinished"></translation>
+        <translation>Minimaliseren naar systeemvak</translation>
     </message>
     <message>
         <location line="+9"/>
         <source>Start in tray</source>
-        <translation type="unfinished"></translation>
+        <translation>Geminimaliseerd opstarten</translation>
     </message>
     <message>
         <location line="+12"/>
         <source>Re-order rooms based on activity</source>
-        <translation type="unfinished"></translation>
+        <translation>Kamers herordenen op basis van activiteit</translation>
     </message>
     <message>
         <location line="+9"/>
         <source>Group&apos;s sidebar</source>
-        <translation type="unfinished"></translation>
+        <translation>Zijbalk van groep</translation>
     </message>
     <message>
         <location line="+9"/>
         <source>Typing notifications</source>
-        <translation type="unfinished"></translation>
+        <translation>Meldingen bij typen van berichten</translation>
     </message>
     <message>
         <location line="+9"/>
         <source>Read receipts</source>
-        <translation type="unfinished">Lees bevestigingen</translation>
+        <translation>Leesbevestigingen</translation>
     </message>
     <message>
         <location line="+9"/>
         <source>Theme</source>
-        <translation type="unfinished"></translation>
+        <translation>Thema</translation>
     </message>
     <message>
         <location line="+10"/>
         <source>GENERAL</source>
-        <translation type="unfinished"></translation>
+        <translation>ALGEMEEN</translation>
     </message>
 </context>
 <context>
@@ -332,7 +332,7 @@
     <message>
         <location filename="../../src/WelcomePage.cc" line="+44"/>
         <source>Welcome to nheko! The desktop client for the Matrix protocol.</source>
-        <translation>Welkom bij nheko! De desktop client voor het Matrix protocol.</translation>
+        <translation>Welkom bij nheko! Dé computerclient voor het Matrix-protocol.</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -342,12 +342,12 @@
     <message>
         <location line="+19"/>
         <source>REGISTER</source>
-        <translation>REGISTREER</translation>
+        <translation>REGISTREREN</translation>
     </message>
     <message>
         <location line="+6"/>
         <source>LOGIN</source>
-        <translation>LOGIN</translation>
+        <translation>INLOGGEN</translation>
     </message>
 </context>
 <context>
@@ -375,12 +375,12 @@
     <message>
         <location line="+8"/>
         <source>Room Visibility</source>
-        <translation>Kamer zichtbaarheid</translation>
+        <translation>Kamerzichtbaarheid</translation>
     </message>
     <message>
         <location line="+9"/>
         <source>Room Preset</source>
-        <translation>Kamer voorinstellingen</translation>
+        <translation>Kamer-voorinstellingen</translation>
     </message>
     <message>
         <location line="+10"/>
@@ -398,7 +398,7 @@
     <message>
         <location line="+11"/>
         <source>User ID to invite</source>
-        <translation>Gebruikers ID om uit te nodigen</translation>
+        <translation>Uit te nodigen gebruikers-id</translation>
     </message>
 </context>
 <context>
@@ -411,7 +411,7 @@
     <message>
         <location line="+11"/>
         <source>Room ID or alias</source>
-        <translation>Kamer ID of alias</translation>
+        <translation>Kamer-id of alias</translation>
     </message>
 </context>
 <context>
@@ -457,8 +457,8 @@
         <source>Media type: %1
 Media size: %2
 </source>
-        <translation>Media type: %1
-Media grootte: %2
+        <translation>Mediasoort: %1
+Mediagrootte: %2
 </translation>
     </message>
 </context>
@@ -477,7 +477,7 @@ Media grootte: %2
     <message>
         <location line="+11"/>
         <source>Solve the reCAPTCHA and press the confirm button</source>
-        <translation>Los de reCAPTCHA op en klik op de bevestigen knop</translation>
+        <translation>Los de reCAPTCHA op en klik op &apos;Bevestigen&apos;</translation>
     </message>
 </context>
 <context>
@@ -485,7 +485,7 @@ Media grootte: %2
     <message>
         <location filename="../../src/dialogs/ReadReceipts.cc" line="+98"/>
         <source>Read receipts</source>
-        <translation>Lees bevestigingen</translation>
+        <translation>Leesbevestigingen</translation>
     </message>
 </context>
 <context>
@@ -498,42 +498,42 @@ Media grootte: %2
     <message>
         <location line="+12"/>
         <source>Notifications</source>
-        <translation type="unfinished"></translation>
+        <translation>Meldingen</translation>
     </message>
     <message>
         <location line="+3"/>
         <source>Muted</source>
-        <translation type="unfinished"></translation>
+        <translation>Gedempt</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Mentions only</source>
-        <translation type="unfinished"></translation>
+        <translation>Alleen vermeldingen</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>All messages</source>
-        <translation type="unfinished"></translation>
+        <translation>Alle berichten</translation>
     </message>
     <message>
         <location line="+8"/>
         <source>Room access</source>
-        <translation type="unfinished"></translation>
+        <translation>Kamertoegang</translation>
     </message>
     <message>
         <location line="+2"/>
         <source>Anyone and guests</source>
-        <translation type="unfinished"></translation>
+        <translation>Iedereen, incl. gasten</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Anyone</source>
-        <translation type="unfinished"></translation>
+        <translation>Iedereen</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Invited users</source>
-        <translation type="unfinished"></translation>
+        <translation>Uitgenodigde gebruikers</translation>
     </message>
 </context>
 <context>
@@ -541,17 +541,17 @@ Media grootte: %2
     <message>
         <location filename="../../src/emoji/Panel.cc" line="+125"/>
         <source>Smileys &amp; People</source>
-        <translation>Smileys &amp; Mensen</translation>
+        <translation>Smileys en mensen</translation>
     </message>
     <message>
         <location line="+4"/>
         <source>Animals &amp; Nature</source>
-        <translation>Dieren &amp; Natuur</translation>
+        <translation>Dieren en natuur</translation>
     </message>
     <message>
         <location line="+3"/>
         <source>Food &amp; Drink</source>
-        <translation>Eten &amp; Drinken</translation>
+        <translation>Eten en drinken</translation>
     </message>
     <message>
         <location line="+3"/>
@@ -561,7 +561,7 @@ Media grootte: %2
     <message>
         <location line="+4"/>
         <source>Travel &amp; Places</source>
-        <translation>Reizen &amp; Locaties</translation>
+        <translation>Reizen en locaties</translation>
     </message>
     <message>
         <location line="+3"/>
