@@ -42,7 +42,7 @@ static const lmdb::val CACHE_FORMAT_VERSION_KEY("cache_format_version");
 constexpr size_t MAX_RESTORED_MESSAGES = 30;
 
 constexpr auto DB_SIZE = 512UL * 1024UL * 1024UL; // 512 MB
-constexpr auto MAX_DBS = 1024UL;
+constexpr auto MAX_DBS = 8092UL;
 
 //! Cache databases and their format.
 //!
@@ -936,6 +936,8 @@ Cache::calculateRoomReadStatus(const std::string &room_id)
 void
 Cache::saveState(const mtx::responses::Sync &res)
 {
+        using namespace mtx::events;
+
         auto txn = lmdb::txn::begin(env_);
 
         setNextBatchToken(txn, res.next_batch);
@@ -957,6 +959,35 @@ Cache::saveState(const mtx::responses::Sync &res)
                   getRoomAvatarUrl(txn, statesdb, membersdb, QString::fromStdString(room.first))
                     .toStdString();
 
+                // Process the account_data associated with this room
+                bool has_new_tags = false;
+                for (const auto &evt : room.second.account_data.events) {
+                        // for now only fetch tag events
+                        if (evt.type() == typeid(Event<account_data::Tag>)) {
+                                auto tags_evt = boost::get<Event<account_data::Tag>>(evt);
+                                has_new_tags  = true;
+                                for (const auto &tag : tags_evt.content.tags) {
+                                        updatedInfo.tags.push_back(tag.first);
+                                }
+                        }
+                }
+                if (!has_new_tags) {
+                        // retrieve the old tags, they haven't changed
+                        lmdb::val data;
+                        if (lmdb::dbi_get(txn, roomsDb_, lmdb::val(room.first), data)) {
+                                try {
+                                        RoomInfo tmp =
+                                          json::parse(std::string(data.data(), data.size()));
+                                        updatedInfo.tags = tmp.tags;
+                                } catch (const json::exception &e) {
+                                        nhlog::db()->warn(
+                                          "failed to parse room info: room_id ({}), {}",
+                                          room.first,
+                                          std::string(data.data(), data.size()));
+                                }
+                        }
+                }
+
                 lmdb::dbi_put(
                   txn, roomsDb_, lmdb::val(room.first), lmdb::val(json(updatedInfo).dump()));
 
@@ -1078,6 +1109,27 @@ Cache::roomsWithStateUpdates(const mtx::responses::Sync &res)
         return rooms;
 }
 
+std::vector<std::string>
+Cache::roomsWithTagUpdates(const mtx::responses::Sync &res)
+{
+        using namespace mtx::events;
+
+        std::vector<std::string> rooms;
+        for (const auto &room : res.rooms.join) {
+                bool hasUpdates = false;
+                for (const auto &evt : room.second.account_data.events) {
+                        if (evt.type() == typeid(Event<account_data::Tag>)) {
+                                hasUpdates = true;
+                        }
+                }
+
+                if (hasUpdates)
+                        rooms.emplace_back(room.first);
+        }
+
+        return rooms;
+}
+
 RoomInfo
 Cache::singleRoomInfo(const std::string &room_id)
 {
@@ -2007,6 +2059,7 @@ Cache::roomMembers(const std::string &room_id)
 
 QHash<QString, QString> Cache::DisplayNames;
 QHash<QString, QString> Cache::AvatarUrls;
+QHash<QString, QString> Cache::UserColors;
 
 QString
 Cache::displayName(const QString &room_id, const QString &user_id)
@@ -2038,6 +2091,16 @@ Cache::avatarUrl(const QString &room_id, const QString &user_id)
         return QString();
 }
 
+QString
+Cache::userColor(const QString &user_id)
+{
+        if (UserColors.contains(user_id)) {
+                return UserColors[user_id];
+        }
+
+        return QString();
+}
+
 void
 Cache::insertDisplayName(const QString &room_id,
                          const QString &user_id,
@@ -2067,3 +2130,21 @@ Cache::removeAvatarUrl(const QString &room_id, const QString &user_id)
         auto fmt = QString("%1 %2").arg(room_id).arg(user_id);
         AvatarUrls.remove(fmt);
 }
+
+void
+Cache::insertUserColor(const QString &user_id, const QString &color_name)
+{
+        UserColors.insert(user_id, color_name);
+}
+
+void
+Cache::removeUserColor(const QString &user_id)
+{
+        UserColors.remove(user_id);
+}
+
+void
+Cache::clearUserColors()
+{
+        UserColors.clear();
+}
