@@ -24,12 +24,12 @@
 #include <QImage>
 #include <QString>
 
-#include <json.hpp>
 #include <lmdb++.h>
 #include <mtx/events/join_rules.hpp>
 #include <mtx/responses.hpp>
 #include <mtxclient/crypto/client.hpp>
 #include <mutex>
+#include <nlohmann/json.hpp>
 
 #include "Logging.h"
 
@@ -115,6 +115,8 @@ struct RoomInfo
         bool guest_access  = false;
         //! Metadata describing the last message in the timeline.
         DescInfo msgInfo;
+        //! The list of tags associated with this room
+        std::vector<std::string> tags;
 };
 
 inline void
@@ -129,6 +131,9 @@ to_json(json &j, const RoomInfo &info)
 
         if (info.member_count != 0)
                 j["member_count"] = info.member_count;
+
+        if (info.tags.size() != 0)
+                j["tags"] = info.tags;
 }
 
 inline void
@@ -143,6 +148,9 @@ from_json(const json &j, RoomInfo &info)
 
         if (j.count("member_count"))
                 info.member_count = j.at("member_count");
+
+        if (j.count("tags"))
+                info.tags = j.at("tags").get<std::vector<std::string>>();
 }
 
 //! Basic information per member;
@@ -274,13 +282,16 @@ public:
 
         static QHash<QString, QString> DisplayNames;
         static QHash<QString, QString> AvatarUrls;
+        static QHash<QString, QString> UserColors;
 
         static std::string displayName(const std::string &room_id, const std::string &user_id);
         static QString displayName(const QString &room_id, const QString &user_id);
         static QString avatarUrl(const QString &room_id, const QString &user_id);
+        static QString userColor(const QString &user_id);
 
         static void removeDisplayName(const QString &room_id, const QString &user_id);
         static void removeAvatarUrl(const QString &room_id, const QString &user_id);
+        static void removeUserColor(const QString &user_id);
 
         static void insertDisplayName(const QString &room_id,
                                       const QString &user_id,
@@ -288,6 +299,9 @@ public:
         static void insertAvatarUrl(const QString &room_id,
                                     const QString &user_id,
                                     const QString &avatar_url);
+        static void insertUserColor(const QString &user_id, const QString &color_name);
+
+        static void clearUserColors();
 
         //! Load saved data for the display names & avatars.
         void populateMembers();
@@ -384,11 +398,16 @@ public:
 
         RoomInfo singleRoomInfo(const std::string &room_id);
         std::vector<std::string> roomsWithStateUpdates(const mtx::responses::Sync &res);
+        std::vector<std::string> roomsWithTagUpdates(const mtx::responses::Sync &res);
         std::map<QString, RoomInfo> getRoomInfo(const std::vector<std::string> &rooms);
         std::map<QString, RoomInfo> roomUpdates(const mtx::responses::Sync &sync)
         {
                 return getRoomInfo(roomsWithStateUpdates(sync));
         }
+        std::map<QString, RoomInfo> roomTagUpdates(const mtx::responses::Sync &sync)
+        {
+                return getRoomInfo(roomsWithTagUpdates(sync));
+        }
 
         //! Calculates which the read status of a room.
         //! Whether all the events in the timeline have been read.
