@@ -136,6 +136,7 @@ signals:
         void initializeEmptyViews(const std::map<QString, mtx::responses::Timeline> &msgs);
         void syncUI(const mtx::responses::Rooms &rooms);
         void syncRoomlist(const std::map<QString, RoomInfo> &updates);
+        void syncTags(const std::map<QString, RoomInfo> &updates);
         void syncTopBar(const std::map<QString, RoomInfo> &updates);
         void dropToLoginPageCb(const QString &msg);
 
@@ -147,6 +148,7 @@ signals:
                            const QImage &icon);
 
         void updateGroupsInfo(const mtx::responses::JoinedGroups &groups);
+        void themeChanged();
 
 private slots:
         void showUnreadMessageNotification(int count);
@@ -195,7 +197,9 @@ private:
         Memberships getMemberships(const std::vector<Collection> &events) const;
 
         //! Update the room with the new notification count.
-        void updateRoomNotificationCount(const QString &room_id, uint16_t notification_count);
+        void updateRoomNotificationCount(const QString &room_id,
+                                         uint16_t notification_count,
+                                         uint16_t highlight_count);
         //! Send desktop notification for the received messages.
         void sendDesktopNotifications(const mtx::responses::Notifications &);
 
