@@ -448,15 +448,15 @@ TextInputWidget::TextInputWidget(QWidget *parent)
         QFont f;
         f.setPointSizeF(f.pointSizeF());
         const int fontHeight    = QFontMetrics(f).height();
-        const int contentHeight = fontHeight * 2.5;
-        const int InputHeight   = fontHeight * 1.5;
+        const int contentHeight = static_cast<int>(fontHeight * 2.5);
+        const int InputHeight   = static_cast<int>(fontHeight * 1.5);
 
         setFixedHeight(contentHeight);
         setCursor(Qt::ArrowCursor);
 
         topLayout_ = new QHBoxLayout();
         topLayout_->setSpacing(0);
-        topLayout_->setContentsMargins(13, 0, 13, 0);
+        topLayout_->setContentsMargins(13, 1, 13, 0);
 
         QIcon send_file_icon;
         send_file_icon.addFile(":/icons/icons/ui/paper-clip-outline.png");
@@ -481,10 +481,10 @@ TextInputWidget::TextInputWidget(QWidget *parent)
                 &FilteredTextEdit::heightChanged,
                 this,
                 [this, InputHeight, contentHeight](int height) {
-                        int textInputHeight =
-                          std::min(MAX_TEXTINPUT_HEIGHT, std::max(height, InputHeight));
                         int widgetHeight =
                           std::min(MAX_TEXTINPUT_HEIGHT, std::max(height, contentHeight));
+                        int textInputHeight =
+                          std::min(widgetHeight - 1, std::max(height, InputHeight));
 
                         setFixedHeight(widgetHeight);
                         input_->setFixedHeight(textInputHeight);
