@@ -34,7 +34,7 @@
 #include "ui/FlatButton.h"
 #include "ui/ToggleButton.h"
 
-#include "version.h"
+#include "config/nheko.h"
 
 UserSettings::UserSettings() { load(); }
 
@@ -42,18 +42,33 @@ void
 UserSettings::load()
 {
         QSettings settings;
-        isTrayEnabled_                = settings.value("user/window/tray", true).toBool();
+        isTrayEnabled_                = settings.value("user/window/tray", false).toBool();
         hasDesktopNotifications_      = settings.value("user/desktop_notifications", true).toBool();
         isStartInTrayEnabled_         = settings.value("user/window/start_in_tray", false).toBool();
-        isOrderingEnabled_            = settings.value("user/room_ordering", true).toBool();
         isGroupViewEnabled_           = settings.value("user/group_view", true).toBool();
         isTypingNotificationsEnabled_ = settings.value("user/typing_notifications", true).toBool();
         isReadReceiptsEnabled_        = settings.value("user/read_receipts", true).toBool();
         theme_                        = settings.value("user/theme", "light").toString();
+        font_                         = settings.value("user/font_family", "default").toString();
+        baseFontSize_ = settings.value("user/font_size", QFont().pointSizeF()).toDouble();
 
         applyTheme();
 }
 
+void
+UserSettings::setFontSize(double size)
+{
+        baseFontSize_ = size;
+        save();
+}
+
+void
+UserSettings::setFontFamily(QString family)
+{
+        font_ = family;
+        save();
+}
+
 void
 UserSettings::setTheme(QString theme)
 {
@@ -92,12 +107,13 @@ UserSettings::save()
         settings.setValue("start_in_tray", isStartInTrayEnabled_);
         settings.endGroup();
 
-        settings.setValue("room_ordering", isOrderingEnabled_);
+        settings.setValue("font_size", baseFontSize_);
         settings.setValue("typing_notifications", isTypingNotificationsEnabled_);
         settings.setValue("read_receipts", isReadReceiptsEnabled_);
         settings.setValue("group_view", isGroupViewEnabled_);
         settings.setValue("desktop_notifications", hasDesktopNotifications_);
         settings.setValue("theme", theme());
+        settings.setValue("font_family", font_);
         settings.endGroup();
 }
 
@@ -154,15 +170,6 @@ UserSettingsPage::UserSettingsPage(QSharedPointer<UserSettings> settings, QWidge
         startInTrayOptionLayout_->addWidget(startInTrayLabel);
         startInTrayOptionLayout_->addWidget(startInTrayToggle_, 0, Qt::AlignRight);
 
-        auto orderRoomLayout = new QHBoxLayout;
-        orderRoomLayout->setContentsMargins(0, OptionMargin, 0, OptionMargin);
-        auto orderLabel = new QLabel(tr("Re-order rooms based on activity"), this);
-        orderLabel->setFont(font);
-        roomOrderToggle_ = new Toggle(this);
-
-        orderRoomLayout->addWidget(orderLabel);
-        orderRoomLayout->addWidget(roomOrderToggle_, 0, Qt::AlignRight);
-
         auto groupViewLayout = new QHBoxLayout;
         groupViewLayout->setContentsMargins(0, OptionMargin, 0, OptionMargin);
         auto groupViewLabel = new QLabel(tr("Group's sidebar"), this);
@@ -201,22 +208,43 @@ UserSettingsPage::UserSettingsPage(QSharedPointer<UserSettings> settings, QWidge
 
         auto scaleFactorOptionLayout = new QHBoxLayout;
         scaleFactorOptionLayout->setContentsMargins(0, OptionMargin, 0, OptionMargin);
-        auto scaleFactorLabel = new QLabel(tr("Scale factor (requires restart)"), this);
+        auto scaleFactorLabel = new QLabel(tr("Scale factor"), this);
         scaleFactorLabel->setFont(font);
         scaleFactorCombo_ = new QComboBox(this);
-        scaleFactorCombo_->addItem("1");
-        scaleFactorCombo_->addItem("1.25");
-        scaleFactorCombo_->addItem("1.5");
-        scaleFactorCombo_->addItem("1.75");
-        scaleFactorCombo_->addItem("2");
-        scaleFactorCombo_->addItem("2.25");
-        scaleFactorCombo_->addItem("2.5");
-        scaleFactorCombo_->addItem("2.75");
-        scaleFactorCombo_->addItem("3");
+        for (double option = 1; option <= 3; option += 0.25)
+                scaleFactorCombo_->addItem(QString::number(option));
 
         scaleFactorOptionLayout->addWidget(scaleFactorLabel);
         scaleFactorOptionLayout->addWidget(scaleFactorCombo_, 0, Qt::AlignRight);
 
+        auto fontSizeOptionLayout = new QHBoxLayout;
+        fontSizeOptionLayout->setContentsMargins(0, OptionMargin, 0, OptionMargin);
+        auto fontSizeLabel = new QLabel(tr("Font size"), this);
+        fontSizeLabel->setFont(font);
+        fontSizeCombo_ = new QComboBox(this);
+        for (double option = 10; option < 17; option += 0.5)
+                fontSizeCombo_->addItem(QString("%1 ").arg(QString::number(option)));
+
+        fontSizeOptionLayout->addWidget(fontSizeLabel);
+        fontSizeOptionLayout->addWidget(fontSizeCombo_, 0, Qt::AlignRight);
+
+        auto fontFamilyOptionLayout = new QHBoxLayout;
+        fontFamilyOptionLayout->setContentsMargins(0, OptionMargin, 0, OptionMargin);
+        auto fontFamilyLabel = new QLabel(tr("Font Family"), this);
+        fontFamilyLabel->setFont(font);
+        fontSelectionCombo_ = new QComboBox(this);
+        QFontDatabase fontDb;
+        auto fontFamilies = fontDb.families();
+        for (const auto &family : fontFamilies) {
+                fontSelectionCombo_->addItem(family);
+        }
+
+        int fontIndex = fontSelectionCombo_->findText(settings_->font());
+        fontSelectionCombo_->setCurrentIndex(fontIndex);
+
+        fontFamilyOptionLayout->addWidget(fontFamilyLabel);
+        fontFamilyOptionLayout->addWidget(fontSelectionCombo_, 0, Qt::AlignRight);
+
         auto themeOptionLayout_ = new QHBoxLayout;
         themeOptionLayout_->setContentsMargins(0, OptionMargin, 0, OptionMargin);
         auto themeLabel_ = new QLabel(tr("Theme"), this);
@@ -226,6 +254,11 @@ UserSettingsPage::UserSettingsPage(QSharedPointer<UserSettings> settings, QWidge
         themeCombo_->addItem("Dark");
         themeCombo_->addItem("System");
 
+        QString themeStr = settings_->theme();
+        themeStr.replace(0, 1, themeStr[0].toUpper());
+        int themeIndex = themeCombo_->findText(themeStr);
+        themeCombo_->setCurrentIndex(themeIndex);
+
         themeOptionLayout_->addWidget(themeLabel_);
         themeOptionLayout_->addWidget(themeCombo_, 0, Qt::AlignRight);
 
@@ -282,7 +315,7 @@ UserSettingsPage::UserSettingsPage(QSharedPointer<UserSettings> settings, QWidge
         encryptionLayout_->addWidget(new HorizontalLine{this});
         encryptionLayout_->addLayout(sessionKeysLayout);
 
-        font.setWeight(65);
+        font.setWeight(QFont::Medium);
 
         auto encryptionLabel_ = new QLabel(tr("ENCRYPTION"), this);
         encryptionLabel_->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Fixed);
@@ -302,8 +335,6 @@ UserSettingsPage::UserSettingsPage(QSharedPointer<UserSettings> settings, QWidge
         mainLayout_->addLayout(trayOptionLayout_);
         mainLayout_->addLayout(startInTrayOptionLayout_);
         mainLayout_->addWidget(new HorizontalLine(this));
-        mainLayout_->addLayout(orderRoomLayout);
-        mainLayout_->addWidget(new HorizontalLine(this));
         mainLayout_->addLayout(groupViewLayout);
         mainLayout_->addWidget(new HorizontalLine(this));
         mainLayout_->addLayout(typingLayout);
@@ -314,11 +345,12 @@ UserSettingsPage::UserSettingsPage(QSharedPointer<UserSettings> settings, QWidge
 #if defined(Q_OS_MAC)
         scaleFactorLabel->hide();
         scaleFactorCombo_->hide();
-#else
-        mainLayout_->addLayout(scaleFactorOptionLayout);
-        mainLayout_->addWidget(new HorizontalLine(this));
 #endif
 
+        mainLayout_->addLayout(scaleFactorOptionLayout);
+        mainLayout_->addLayout(fontSizeOptionLayout);
+        mainLayout_->addLayout(fontFamilyOptionLayout);
+        mainLayout_->addWidget(new HorizontalLine(this));
         mainLayout_->addLayout(themeOptionLayout_);
         mainLayout_->addWidget(new HorizontalLine(this));
 
@@ -347,11 +379,19 @@ UserSettingsPage::UserSettingsPage(QSharedPointer<UserSettings> settings, QWidge
 
         connect(themeCombo_,
                 static_cast<void (QComboBox::*)(const QString &)>(&QComboBox::activated),
-                [this](const QString &text) { settings_->setTheme(text.toLower()); });
+                [this](const QString &text) {
+                        settings_->setTheme(text.toLower());
+                        emit themeChanged();
+                });
         connect(scaleFactorCombo_,
                 static_cast<void (QComboBox::*)(const QString &)>(&QComboBox::activated),
                 [](const QString &factor) { utils::setScaleFactor(factor.toFloat()); });
-
+        connect(fontSizeCombo_,
+                static_cast<void (QComboBox::*)(const QString &)>(&QComboBox::activated),
+                [this](const QString &size) { settings_->setFontSize(size.trimmed().toDouble()); });
+        connect(fontSelectionCombo_,
+                static_cast<void (QComboBox::*)(const QString &)>(&QComboBox::activated),
+                [this](const QString &family) { settings_->setFontFamily(family.trimmed()); });
         connect(trayToggle_, &Toggle::toggled, this, [this](bool isDisabled) {
                 settings_->setTray(!isDisabled);
                 if (isDisabled) {
@@ -366,10 +406,6 @@ UserSettingsPage::UserSettingsPage(QSharedPointer<UserSettings> settings, QWidge
                 settings_->setStartInTray(!isDisabled);
         });
 
-        connect(roomOrderToggle_, &Toggle::toggled, this, [this](bool isDisabled) {
-                settings_->setRoomOrdering(!isDisabled);
-        });
-
         connect(groupViewToggle_, &Toggle::toggled, this, [this](bool isDisabled) {
                 settings_->setGroupView(!isDisabled);
         });
@@ -395,13 +431,14 @@ UserSettingsPage::UserSettingsPage(QSharedPointer<UserSettings> settings, QWidge
 void
 UserSettingsPage::showEvent(QShowEvent *)
 {
-        restoreThemeCombo();
-        restoreScaleFactor();
+        // FIXME macOS doesn't show the full option unless a space is added.
+        utils::restoreCombobox(fontSizeCombo_, QString::number(settings_->fontSize()) + " ");
+        utils::restoreCombobox(scaleFactorCombo_, QString::number(utils::scaleFactor()));
+        utils::restoreCombobox(themeCombo_, settings_->theme());
 
         // FIXME: Toggle treats true as "off"
         trayToggle_->setState(!settings_->isTrayEnabled());
         startInTrayToggle_->setState(!settings_->isStartInTrayEnabled());
-        roomOrderToggle_->setState(!settings_->isOrderingEnabled());
         groupViewToggle_->setState(!settings_->isGroupViewEnabled());
         typingNotifications_->setState(!settings_->isTypingNotificationsEnabled());
         readReceipts_->setState(!settings_->isReadReceiptsEnabled());
@@ -431,44 +468,6 @@ UserSettingsPage::paintEvent(QPaintEvent *)
         style()->drawPrimitive(QStyle::PE_Widget, &opt, &p, this);
 }
 
-void
-UserSettingsPage::restoreScaleFactor() const
-{
-        auto factor = utils::scaleFactor();
-
-        if (factor == 1)
-                scaleFactorCombo_->setCurrentIndex(0);
-        else if (factor == 1.25)
-                scaleFactorCombo_->setCurrentIndex(1);
-        else if (factor == 1.5)
-                scaleFactorCombo_->setCurrentIndex(2);
-        else if (factor == 1.75)
-                scaleFactorCombo_->setCurrentIndex(3);
-        else if (factor == 2)
-                scaleFactorCombo_->setCurrentIndex(4);
-        else if (factor == 2.25)
-                scaleFactorCombo_->setCurrentIndex(5);
-        else if (factor == 2.5)
-                scaleFactorCombo_->setCurrentIndex(6);
-        else if (factor == 2.75)
-                scaleFactorCombo_->setCurrentIndex(7);
-        else if (factor == 3)
-                scaleFactorCombo_->setCurrentIndex(7);
-        else
-                scaleFactorCombo_->setCurrentIndex(0);
-}
-
-void
-UserSettingsPage::restoreThemeCombo() const
-{
-        if (settings_->theme() == "light")
-                themeCombo_->setCurrentIndex(0);
-        else if (settings_->theme() == "dark")
-                themeCombo_->setCurrentIndex(1);
-        else
-                themeCombo_->setCurrentIndex(2);
-}
-
 void
 UserSettingsPage::importSessionKeys()
 {
