@@ -14,6 +14,10 @@
 #include <mtx/events/collections.hpp>
 #include <mtx/events/common.hpp>
 
+#include <qmath.h>
+
+class QComboBox;
+
 namespace utils {
 
 using TimelineEvent = mtx::events::collections::TimelineEvents;
@@ -225,7 +229,38 @@ markdownToHtml(const QString &text);
 QString
 linkColor();
 
+//! Returns the hash code of the input QString
+int
+hashQString(const QString &input);
+
+//! Generate a color (matching #RRGGBB) that has an acceptable contrast to background that is based
+//! on the input string.
+QString
+generateContrastingHexColor(const QString &input, const QString &background);
+
+//! Given two luminance values, compute the contrast ratio between them.
+qreal
+computeContrast(const qreal &one, const qreal &two);
+
+//! Compute the luminance of a single color.  Based on https://stackoverflow.com/a/9733420
+qreal
+luminance(const QColor &col);
+
 //! Center a widget in relation to another widget.
 void
 centerWidget(QWidget *widget, QWidget *parent);
+
+void
+restoreCombobox(QComboBox *combo, const QString &value);
+
+struct SideBarSizes
+{
+        int small;
+        int normal;
+        int groups;
+        int collapsePoint;
+};
+
+SideBarSizes
+calculateSidebarSizes(const QFont &f);
 }
