@@ -35,6 +35,7 @@ protected:
 
 signals:
         void closing();
+        void saving();
 
 private:
         QPixmap originalImage_;
@@ -42,6 +43,7 @@ private:
 
         QRect content_;
         QRect close_button_;
+        QRect save_button_;
         QRect screen_;
 };
 } // dialogs
