@@ -22,7 +22,6 @@
 #include <QFile>
 #include <QFontDatabase>
 #include <QLabel>
-#include <QLayout>
 #include <QLibraryInfo>
 #include <QMessageBox>
 #include <QPoint>
@@ -36,7 +35,7 @@
 #include "MatrixClient.h"
 #include "RunGuard.h"
 #include "Utils.h"
-#include "version.h"
+#include "config/nheko.h"
 
 #if defined(Q_OS_MAC)
 #include "emoji/MacHelper.h"
@@ -113,9 +112,6 @@ main(int argc, char *argv[])
 
                 if (factor != -1)
                         qputenv("QT_SCALE_FACTOR", QString::number(factor).toUtf8());
-
-                if (factor == -1 || factor == 1)
-                        qputenv("QT_AUTO_SCREEN_SCALE_FACTOR", "1");
         }
 #endif
 
@@ -124,6 +120,7 @@ main(int argc, char *argv[])
         QCoreApplication::setApplicationVersion(nheko::version);
         QCoreApplication::setOrganizationName("nheko");
         QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+        QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
 
         QCommandLineParser parser;
         parser.addHelpOption();
@@ -155,11 +152,13 @@ main(int argc, char *argv[])
 
         QSettings settings;
 
-        // Set the default if a value has not been set.
-        if (settings.value("font/size").toInt() == 0)
-                settings.setValue("font/size", 12);
+        QFont font;
+        QString userFontFamily = settings.value("user/font_family", "").toString();
+        if (!userFontFamily.isEmpty()) {
+                font.setFamily(userFontFamily);
+        }
+        font.setPointSizeF(settings.value("user/font_size", font.pointSizeF()).toDouble());
 
-        QFont font("Open Sans", settings.value("font/size").toInt());
         app.setFont(font);
 
         QString lang = QLocale::system().name();
