@@ -14,6 +14,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
+#include <functional>
 
 #include <QContextMenuEvent>
 #include <QDesktopServices>
@@ -28,6 +29,7 @@
 #include "Olm.h"
 #include "ui/Avatar.h"
 #include "ui/Painter.h"
+#include "ui/TextLabel.h"
 
 #include "timeline/TimelineItem.h"
 #include "timeline/widgets/AudioItem.h"
@@ -41,86 +43,6 @@
 constexpr int MSG_RIGHT_MARGIN = 7;
 constexpr int MSG_PADDING      = 20;
 
-TextLabel::TextLabel(QWidget *parent)
-  : TextLabel(QString(), parent)
-{}
-
-TextLabel::TextLabel(const QString &text, QWidget *parent)
-  : QTextBrowser(parent)
-{
-        document()->setDefaultStyleSheet(QString("a {color: %1; }").arg(utils::linkColor()));
-
-        setText(text);
-        setOpenExternalLinks(true);
-
-        // Make it look and feel like an ordinary label.
-        setReadOnly(true);
-        setFrameStyle(QFrame::NoFrame);
-        QPalette pal = palette();
-        pal.setColor(QPalette::Base, Qt::transparent);
-        setPalette(pal);
-
-        // Wrap anywhere but prefer words, adjust minimum height on the fly.
-        setLineWrapMode(QTextEdit::WidgetWidth);
-        setWordWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere);
-        connect(document()->documentLayout(),
-                &QAbstractTextDocumentLayout::documentSizeChanged,
-                this,
-                &TextLabel::adjustHeight);
-        document()->setDocumentMargin(0);
-
-        setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
-        setFixedHeight(0);
-
-        connect(this, &TextLabel::linkActivated, this, [](const QUrl &url) {
-                auto parts          = url.toString().split('/');
-                auto defaultHandler = [](const QUrl &url) { QDesktopServices::openUrl(url); };
-
-                if (url.host() != "matrix.to" || parts.isEmpty())
-                        return defaultHandler(url);
-
-                try {
-                        using namespace mtx::identifiers;
-                        parse<User>(parts.last().toStdString());
-                } catch (const std::exception &) {
-                        return defaultHandler(url);
-                }
-
-                auto user_id = parts.last();
-                auto room_id = ChatPage::instance()->currentRoom();
-
-                MainWindow::instance()->openUserProfile(user_id, room_id);
-        });
-}
-
-void
-TextLabel::focusOutEvent(QFocusEvent *e)
-{
-        QTextBrowser::focusOutEvent(e);
-
-        QTextCursor cursor = textCursor();
-        cursor.clearSelection();
-        setTextCursor(cursor);
-}
-
-void
-TextLabel::mousePressEvent(QMouseEvent *e)
-{
-        link_ = (e->button() & Qt::LeftButton) ? anchorAt(e->pos()) : QString();
-        QTextBrowser::mousePressEvent(e);
-}
-
-void
-TextLabel::mouseReleaseEvent(QMouseEvent *e)
-{
-        if (e->button() & Qt::LeftButton && !link_.isEmpty() && anchorAt(e->pos()) == link_) {
-                emit linkActivated(link_);
-                return;
-        }
-
-        QTextBrowser::mouseReleaseEvent(e);
-}
-
 StatusIndicator::StatusIndicator(QWidget *parent)
   : QWidget(parent)
 {
@@ -234,12 +156,6 @@ TimelineItem::init()
         userName_   = nullptr;
         body_       = nullptr;
 
-        font_.setPixelSize(conf::fontSize);
-        usernameFont_ = font_;
-        usernameFont_.setWeight(60);
-
-        QFontMetrics fm(font_);
-
         contextMenu_      = new QMenu(this);
         showReadReceipts_ = new QAction("Read receipts", this);
         markAsRead_       = new QAction("Mark as read", this);
@@ -277,10 +193,17 @@ TimelineItem::init()
                                   emit eventRedacted(event_id_);
                           });
         });
-
+        connect(
+          ChatPage::instance(), &ChatPage::themeChanged, this, &TimelineItem::refreshAuthorColor);
         connect(markAsRead_, &QAction::triggered, this, &TimelineItem::sendReadReceipt);
         connect(viewRawMessage_, &QAction::triggered, this, &TimelineItem::openRawMessageViewer);
 
+        colorGenerating_ = new QFutureWatcher<QString>(this);
+        connect(colorGenerating_,
+                &QFutureWatcher<QString>::finished,
+                this,
+                &TimelineItem::finishedGeneratingColor);
+
         topLayout_     = new QHBoxLayout(this);
         mainLayout_    = new QVBoxLayout;
         messageLayout_ = new QHBoxLayout;
@@ -295,9 +218,11 @@ TimelineItem::init()
         mainLayout_->setContentsMargins(conf::timeline::headerLeftMargin, 0, 0, 0);
         mainLayout_->setSpacing(0);
 
-        QFont timestampFont;
-        timestampFont.setPixelSize(conf::timeline::fonts::indicator);
-        QFontMetrics tsFm(timestampFont);
+        timestampFont_.setPointSizeF(timestampFont_.pointSizeF() * 0.9);
+        timestampFont_.setFamily("Monospace");
+        timestampFont_.setStyleHint(QFont::Monospace);
+
+        QFontMetrics tsFm(timestampFont_);
 
         statusIndicator_ = new StatusIndicator(this);
         statusIndicator_->setFixedWidth(tsFm.height() - tsFm.leading());
@@ -639,6 +564,12 @@ TimelineItem::TimelineItem(const mtx::events::RoomEvent<mtx::events::msg::Text>
         adjustMessageLayout();
 }
 
+TimelineItem::~TimelineItem()
+{
+        colorGenerating_->cancel();
+        colorGenerating_->waitForFinished();
+}
+
 void
 TimelineItem::markSent()
 {
@@ -678,10 +609,55 @@ void
 TimelineItem::generateBody(const QString &body)
 {
         body_ = new TextLabel(replaceEmoji(body), this);
-        body_->setFont(font_);
         body_->setTextInteractionFlags(Qt::TextSelectableByMouse | Qt::TextBrowserInteraction);
+
+        connect(body_, &TextLabel::userProfileTriggered, this, [](const QString &user_id) {
+                MainWindow::instance()->openUserProfile(user_id,
+                                                        ChatPage::instance()->currentRoom());
+        });
 }
 
+void
+TimelineItem::refreshAuthorColor()
+{
+        // Cancel and wait if we are already generating the color.
+        if (colorGenerating_->isRunning()) {
+                colorGenerating_->cancel();
+                colorGenerating_->waitForFinished();
+        }
+        if (userName_) {
+                // generate user's unique color.
+                std::function<QString()> generate = [this]() {
+                        QString userColor = utils::generateContrastingHexColor(
+                          userName_->toolTip(), backgroundColor().name());
+                        return userColor;
+                };
+
+                QString userColor = Cache::userColor(userName_->toolTip());
+
+                // If the color is empty, then generate it asynchronously
+                if (userColor.isEmpty()) {
+                        colorGenerating_->setFuture(QtConcurrent::run(generate));
+                } else {
+                        userName_->setStyleSheet("QLabel { color : " + userColor + "; }");
+                }
+        }
+}
+
+void
+TimelineItem::finishedGeneratingColor()
+{
+        nhlog::ui()->debug("finishedGeneratingColor for: {}", userName_->toolTip().toStdString());
+        QString userColor = colorGenerating_->result();
+
+        if (!userColor.isEmpty()) {
+                // another TimelineItem might have inserted in the meantime.
+                if (Cache::userColor(userName_->toolTip()).isEmpty()) {
+                        Cache::insertUserColor(userName_->toolTip(), userColor);
+                }
+                userName_->setStyleSheet("QLabel { color : " + userColor + "; }");
+        }
+}
 // The username/timestamp is displayed along with the message body.
 void
 TimelineItem::generateBody(const QString &user_id, const QString &displayname, const QString &body)
@@ -701,10 +677,14 @@ TimelineItem::generateUserName(const QString &user_id, const QString &displaynam
                         sender = displayname.split(":")[0].split("@")[1];
         }
 
-        QFontMetrics fm(usernameFont_);
+        QFont usernameFont;
+        usernameFont.setPointSizeF(usernameFont.pointSizeF() * 1.1);
+        usernameFont.setWeight(QFont::Medium);
+
+        QFontMetrics fm(usernameFont);
 
         userName_ = new QLabel(this);
-        userName_->setFont(usernameFont_);
+        userName_->setFont(usernameFont);
         userName_->setText(fm.elidedText(sender, Qt::ElideRight, 500));
         userName_->setToolTip(user_id);
         userName_->setToolTipDuration(1500);
@@ -712,6 +692,10 @@ TimelineItem::generateUserName(const QString &user_id, const QString &displaynam
         userName_->setAlignment(Qt::AlignLeft | Qt::AlignTop);
         userName_->setFixedWidth(QFontMetrics(userName_->font()).width(userName_->text()));
 
+        // Set the user color asynchronously if it hasn't been generated yet,
+        // otherwise this will just set it.
+        refreshAuthorColor();
+
         auto filter = new UserProfileFilter(user_id, userName_);
         userName_->installEventFilter(filter);
         userName_->setCursor(Qt::PointingHandCursor);
@@ -736,13 +720,8 @@ TimelineItem::generateUserName(const QString &user_id, const QString &displaynam
 void
 TimelineItem::generateTimestamp(const QDateTime &time)
 {
-        QFont timestampFont;
-        timestampFont.setFamily("Monospace");
-        timestampFont.setStyleHint(QFont::Monospace);
-        timestampFont.setPixelSize(conf::timeline::fonts::timestamp);
-
         timestamp_ = new QLabel(this);
-        timestamp_->setFont(timestampFont);
+        timestamp_->setFont(timestampFont_);
         timestamp_->setText(
           QString("<span style=\"color: #999\"> %1 </span>").arg(time.toString("HH:mm")));
 }
@@ -757,9 +736,7 @@ TimelineItem::replaceEmoji(const QString &body)
         for (auto &code : utf32_string) {
                 // TODO: Be more precise here.
                 if (code > 9000)
-                        fmtBody += QString("<span style=\"font-family: Emoji "
-                                           "One; font-size: %1px\">")
-                                     .arg(conf::emojiSize) +
+                        fmtBody += QString("<span style=\"font-family:  emoji;\">") +
                                    QString::fromUcs4(&code, 1) + "</span>";
                 else
                         fmtBody += QString::fromUcs4(&code, 1);
@@ -774,9 +751,12 @@ TimelineItem::setupAvatarLayout(const QString &userName)
         topLayout_->setContentsMargins(
           conf::timeline::msgLeftMargin, conf::timeline::msgAvatarTopMargin, 0, 0);
 
+        QFont f;
+        f.setPointSizeF(f.pointSizeF());
+
         userAvatar_ = new Avatar(this);
         userAvatar_->setLetter(QChar(userName[0]).toUpper());
-        userAvatar_->setSize(conf::timeline::avatarSize);
+        userAvatar_->setSize(QFontMetrics(f).height() * 2);
 
         // TODO: The provided user name should be a UserId class
         if (userName[0] == '@' && userName.size() > 1)
@@ -792,8 +772,11 @@ TimelineItem::setupAvatarLayout(const QString &userName)
 void
 TimelineItem::setupSimpleLayout()
 {
-        topLayout_->setContentsMargins(conf::timeline::msgLeftMargin + conf::timeline::avatarSize +
-                                         2,
+        QFont f;
+        f.setPointSizeF(f.pointSizeF());
+
+        topLayout_->setContentsMargins(conf::timeline::msgLeftMargin +
+                                         QFontMetrics(f).height() * 2 + 2,
                                        conf::timeline::msgTopMargin,
                                        0,
                                        0);
@@ -932,4 +915,4 @@ TimelineItem::openRawMessageViewer() const
                             "failed to serialize event ({}, {})", room_id, event_id);
                   }
           });
-}
+}
\ No newline at end of file
